aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorFerenc Toth <feri@gawker.com>2015-08-21 09:19:10 +0200
committerFerenc Toth <feri@gawker.com>2015-08-25 10:15:11 +0200
commit2668550433cc0629affc7e74daa4693634965a4e (patch)
treed151772295ca642d6f7f6975a059bf42c1986898
parentb1efc3ba5d981b7fe1e1a21af41081517e17c9fe (diff)
downloadKamon-2668550433cc0629affc7e74daa4693634965a4e.tar.gz
Kamon-2668550433cc0629affc7e74daa4693634965a4e.tar.bz2
Kamon-2668550433cc0629affc7e74daa4693634965a4e.zip
= system-metrics: Generic mem metrics
= use generalized entity recorder = merge memory metrics = update tests
-rw-r--r--kamon-system-metrics/src/main/scala/kamon/system/SystemMetricsExtension.scala4
-rw-r--r--kamon-system-metrics/src/main/scala/kamon/system/jmx/HeapMemoryMetrics.scala49
-rw-r--r--kamon-system-metrics/src/main/scala/kamon/system/jmx/MemoryUsageMetrics.scala (renamed from kamon-system-metrics/src/main/scala/kamon/system/jmx/MemoryPoolMetrics.scala)41
-rw-r--r--kamon-system-metrics/src/main/scala/kamon/system/jmx/NonHeapMemoryMetrics.scala53
-rw-r--r--kamon-system-metrics/src/test/scala/kamon/metrics/SystemMetricsSpec.scala20
5 files changed, 32 insertions, 135 deletions
diff --git a/kamon-system-metrics/src/main/scala/kamon/system/SystemMetricsExtension.scala b/kamon-system-metrics/src/main/scala/kamon/system/SystemMetricsExtension.scala
index 9d2a5b94..6ace80cc 100644
--- a/kamon-system-metrics/src/main/scala/kamon/system/SystemMetricsExtension.scala
+++ b/kamon-system-metrics/src/main/scala/kamon/system/SystemMetricsExtension.scala
@@ -55,11 +55,9 @@ class SystemMetricsExtension(system: ExtendedActorSystem) extends Kamon.Extensio
// JMX Metrics
if (jmxEnabled) {
- MemoryPoolMetrics.register(metricsExtension)
+ MemoryUsageMetrics.register(metricsExtension)
ClassLoadingMetrics.register(metricsExtension)
GarbageCollectionMetrics.register(metricsExtension)
- HeapMemoryMetrics.register(metricsExtension)
- NonHeapMemoryMetrics.register(metricsExtension)
ThreadsMetrics.register(metricsExtension)
}
}
diff --git a/kamon-system-metrics/src/main/scala/kamon/system/jmx/HeapMemoryMetrics.scala b/kamon-system-metrics/src/main/scala/kamon/system/jmx/HeapMemoryMetrics.scala
deleted file mode 100644
index cd2e3e8e..00000000
--- a/kamon-system-metrics/src/main/scala/kamon/system/jmx/HeapMemoryMetrics.scala
+++ /dev/null
@@ -1,49 +0,0 @@
-/*
- * =========================================================================================
- * Copyright © 2013-2015 the kamon project <http://kamon.io/>
- *
- * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file
- * except in compliance with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software distributed under the
- * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
- * either express or implied. See the License for the specific language governing permissions
- * and limitations under the License.
- * =========================================================================================
- */
-
-package kamon.system.jmx
-
-import java.lang.management.ManagementFactory
-
-import kamon.metric.GenericEntityRecorder
-import kamon.metric.instrument.{ Memory, InstrumentFactory }
-
-/**
- * Heap Memory metrics, as reported by JMX:
- * - @see [[http://docs.oracle.com/javase/7/docs/api/java/lang/management/MemoryMXBean.html "MemoryMXBean"]]
- */
-class HeapMemoryMetrics(instrumentFactory: InstrumentFactory) extends GenericEntityRecorder(instrumentFactory) {
- val memoryBean = ManagementFactory.getMemoryMXBean
- def nonHeapUsage = memoryBean.getHeapMemoryUsage
-
- gauge("heap-used", Memory.Bytes, () ⇒ {
- nonHeapUsage.getUsed
- })
-
- gauge("heap-max", Memory.Bytes, () ⇒ {
- nonHeapUsage.getMax
- })
-
- gauge("heap-committed", Memory.Bytes, () ⇒ {
- nonHeapUsage.getCommitted
- })
-
-}
-
-object HeapMemoryMetrics extends JmxSystemMetricRecorderCompanion("heap-memory") {
- def apply(instrumentFactory: InstrumentFactory): HeapMemoryMetrics =
- new HeapMemoryMetrics(instrumentFactory)
-}
diff --git a/kamon-system-metrics/src/main/scala/kamon/system/jmx/NonHeapMemoryMetrics.scala b/kamon-system-metrics/src/main/scala/kamon/system/jmx/NonHeapMemoryMetrics.scala
deleted file mode 100644
index 7425972b..00000000
--- a/kamon-system-metrics/src/main/scala/kamon/system/jmx/NonHeapMemoryMetrics.scala
+++ /dev/null
@@ -1,53 +0,0 @@
-/*
- * =========================================================================================
- * Copyright © 2013-2015 the kamon project <http://kamon.io/>
- *
- * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file
- * except in compliance with the License. You may obtain a copy of the License at
- *
- * http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software distributed under the
- * License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
- * either express or implied. See the License for the specific language governing permissions
- * and limitations under the License.
- * =========================================================================================
- */
-
-package kamon.system.jmx
-
-import java.lang.management.ManagementFactory
-
-import kamon.metric.GenericEntityRecorder
-import kamon.metric.instrument.{ Memory, InstrumentFactory }
-
-/**
- * Non Heap Memory metrics, as reported by JMX:
- * - @see [[http://docs.oracle.com/javase/7/docs/api/java/lang/management/MemoryMXBean.html "MemoryMXBean"]]
- */
-class NonHeapMemoryMetrics(instrumentFactory: InstrumentFactory) extends GenericEntityRecorder(instrumentFactory) {
- val memoryBean = ManagementFactory.getMemoryMXBean
- def nonHeapUsage = memoryBean.getNonHeapMemoryUsage
-
- gauge("non-heap-used", Memory.Bytes, () ⇒ {
- nonHeapUsage.getUsed
- })
-
- gauge("non-heap-max", Memory.Bytes, () ⇒ {
- val max = nonHeapUsage.getMax
-
- // .getMax can return -1 if the max is not defined.
- if (max >= 0) max
- else 0
- })
-
- gauge("non-heap-committed", Memory.Bytes, () ⇒ {
- nonHeapUsage.getCommitted
- })
-
-}
-
-object NonHeapMemoryMetrics extends JmxSystemMetricRecorderCompanion("non-heap-memory") {
- def apply(instrumentFactory: InstrumentFactory): NonHeapMemoryMetrics =
- new NonHeapMemoryMetrics(instrumentFactory)
-}
diff --git a/kamon-system-metrics/src/test/scala/kamon/metrics/SystemMetricsSpec.scala b/kamon-system-metrics/src/test/scala/kamon/metrics/SystemMetricsSpec.scala
index 4d633952..7af704d5 100644
--- a/kamon-system-metrics/src/test/scala/kamon/metrics/SystemMetricsSpec.scala
+++ b/kamon-system-metrics/src/test/scala/kamon/metrics/SystemMetricsSpec.scala
@@ -62,20 +62,16 @@ class SystemMetricsSpec extends BaseKamonSpec("system-metrics-spec") with Redire
}
}
- "record used, max and committed heap metrics" in {
- val heapMetrics = takeSnapshotOf("heap-memory", "system-metric")
+ "record used, max and committed heap and non-heap metrics" in {
+ val memoryMetrics = takeSnapshotOf("jmx-memory", "system-metric")
- heapMetrics.gauge("heap-used").get.numberOfMeasurements should be > 0L
- heapMetrics.gauge("heap-max").get.numberOfMeasurements should be > 0L
- heapMetrics.gauge("heap-committed").get.numberOfMeasurements should be > 0L
- }
-
- "record used, max and committed non-heap metrics" in {
- val nonHeapMetrics = takeSnapshotOf("non-heap-memory", "system-metric")
+ memoryMetrics.gauge("heap-used").get.numberOfMeasurements should be > 0L
+ memoryMetrics.gauge("heap-max").get.numberOfMeasurements should be > 0L
+ memoryMetrics.gauge("heap-committed").get.numberOfMeasurements should be > 0L
- nonHeapMetrics.gauge("non-heap-used").get.numberOfMeasurements should be > 0L
- nonHeapMetrics.gauge("non-heap-max").get.numberOfMeasurements should be > 0L
- nonHeapMetrics.gauge("non-heap-committed").get.numberOfMeasurements should be > 0L
+ memoryMetrics.gauge("non-heap-used").get.numberOfMeasurements should be > 0L
+ memoryMetrics.gauge("non-heap-max").get.numberOfMeasurements should be > 0L
+ memoryMetrics.gauge("non-heap-committed").get.numberOfMeasurements should be > 0L
}
"record daemon, count and peak jvm threads metrics" in {
diff --git a/kamon-system-metrics/src/main/scala/kamon/system/jmx/MemoryPoolMetrics.scala b/kamon-system-metrics/src/main/scala/kamon/system/jmx/MemoryUsageMetrics.scala
index 8c2d2293..ef9d47a6 100644
--- a/kamon-system-metrics/src/main/scala/kamon/system/jmx/MemoryPoolMetrics.scala
+++ b/kamon-system-metrics/src/main/scala/kamon/system/jmx/MemoryUsageMetrics.scala
@@ -16,29 +16,29 @@
package kamon.system.jmx
-import java.lang.management.{ ManagementFactory, MemoryPoolMXBean }
+import java.lang.management.{ MemoryUsage, MemoryMXBean, ManagementFactory, MemoryPoolMXBean }
import kamon.metric.GenericEntityRecorder
-import kamon.metric.instrument.{ InstrumentFactory, Memory }
+import kamon.metric.instrument.{ Memory, InstrumentFactory }
import scala.collection.convert.WrapAsScala
/**
* Generic memory pool stat recorder.
* Records the amount of used, max, and committed memory in bytes for each passed MemoryPoolMXBean.
* @param instrumentFactory Helpers for metric recording.
* @param beansWithNames Data sources with metric name prefixes.
*/
-class MemoryPoolMetrics(instrumentFactory: InstrumentFactory,
- beansWithNames: Iterable[MemoryBeanWithMetricName]) extends GenericEntityRecorder(instrumentFactory) {
+class MemoryUsageMetrics(instrumentFactory: InstrumentFactory,
+ beansWithNames: Iterable[MemoryUsageWithMetricName]) extends GenericEntityRecorder(instrumentFactory) {
beansWithNames.foreach {
- case MemoryBeanWithMetricName(name, bean) ⇒
+ case MemoryUsageWithMetricName(name, bean) ⇒
gauge(name + "-used", Memory.Bytes, () ⇒ {
- bean.getUsage.getUsed
+ bean.getUsed
})
gauge(name + "-max", Memory.Bytes, () ⇒ {
- val max = bean.getUsage.getMax
+ val max = bean.getMax
// .getMax can return -1 if the max is not defined.
if (max >= 0) max
@@ -46,17 +46,17 @@ class MemoryPoolMetrics(instrumentFactory: InstrumentFactory,
})
gauge(name + "-committed", Memory.Bytes, () ⇒ {
- bean.getUsage.getCommitted
+ bean.getCommitted
})
}
}
/**
* Objects of this kind may be passed to [[MemoryPoolMetrics]] for data collection.
* @param metricName The sanitized name of a [[MemoryPoolMXBean]].
* @param bean The data source for metrics.
*/
-private[jmx] final case class MemoryBeanWithMetricName(metricName: String, bean: MemoryPoolMXBean)
+private[jmx] final case class MemoryUsageWithMetricName(metricName: String, bean: MemoryUsage)
/**
* Memory Pool metrics, as reported by JMX:
@@ -64,17 +64,22 @@ private[jmx] final case class MemoryBeanWithMetricName(metricName: String, bean:
* Pools in HotSpot Java 8:
* code-cache, metaspace, compressed-class-space, ps-eden-space, ps-survivor-space, ps-old-gen
*/
-object MemoryPoolMetrics extends JmxSystemMetricRecorderCompanion("memory-pool") with WrapAsScala {
+object MemoryUsageMetrics extends JmxSystemMetricRecorderCompanion("jmx-memory") with WrapAsScala {
private val invalidChars = """[^a-z0-9]""".r
private def sanitizedName(memoryPoolMXBean: MemoryPoolMXBean) =
invalidChars.replaceAllIn(memoryPoolMXBean.getName.toLowerCase, "-")
- private val beansWithNames = ManagementFactory.getMemoryPoolMXBeans.toIterable.map { bean ⇒
- MemoryBeanWithMetricName(sanitizedName(bean), bean)
+ private val usagesWithNames = ManagementFactory.getMemoryPoolMXBeans.toList.map { bean ⇒
+ MemoryUsageWithMetricName(sanitizedName(bean), bean.getUsage)
}
- def apply(instrumentFactory: InstrumentFactory): MemoryPoolMetrics =
- new MemoryPoolMetrics(instrumentFactory, beansWithNames)
+ private val memoryMXBean: MemoryMXBean = ManagementFactory.getMemoryMXBean
+
+ def apply(instrumentFactory: InstrumentFactory): MemoryUsageMetrics =
+ new MemoryUsageMetrics(instrumentFactory,
+ MemoryUsageWithMetricName("non-heap", memoryMXBean.getNonHeapMemoryUsage) ::
+ MemoryUsageWithMetricName("heap", memoryMXBean.getHeapMemoryUsage) ::
+ usagesWithNames)
}
@@ -16,29 +16,29 @@
import scala.collection.convert.WrapAsScala
/**
- * Generic memory pool stat recorder.
- * Records the amount of used, max, and committed memory in bytes for each passed MemoryPoolMXBean.
+ * Generic memory usage stat recorder.
+ * Records the amount of used, max, and committed memory in bytes for each passed MemoryUsage.
* @param instrumentFactory Helpers for metric recording.
* @param beansWithNames Data sources with metric name prefixes.
@@ -46,17 +46,17 @@ class MemoryPoolMetrics(instrumentFactory: InstrumentFactory,
}
/**
- * Objects of this kind may be passed to [[MemoryPoolMetrics]] for data collection.
- * @param metricName The sanitized name of a [[MemoryPoolMXBean]].
+ * Objects of this kind may be passed to instances of [[MemoryUsageMetrics]] for data collection.
+ * @param metricName The sanitized name for a metric.
* @param bean The data source for metrics.
*/